@@ -55,7 +55,7 @@
 
 static const char program[] = STRINGIFY(PROGRAM);
 static const char library[] = STRINGIFY(LIBRARY);
-static const char verdate[] = "0.9.2 -- 2020-12-27 11:22"; // $ date +'%F %R'
+static const char verdate[] = "0.9.3 -- 2021-06-05 11:07"; // $ date +'%F %R'
 
 static const char license[] =
 "Copyright (C) 2016, 2017, 2018, 2019, 2020, 2021  Stefan Vargyas.\n"
@@ -662,6 +662,9 @@ static void usage(void)
         "                                 otherwise do not (default not)\n"
         "     --[no-]newline-sep        separate the top values on terse JSON print outs\n"
         "                                 by newline or otherwise do not (default not)\n"
+        "     --[no-]sort-keys          sort the key names of each JSON sub-object in the\n"
+        "                                 JSON input when action is `-M|--from-ast-print'\n"
+        "                                 or otherwise do not (default not)\n"
         "     --[no-]warning            print out warning reports on stderr or otherwise\n"
         "                                 do not (default do)\n"
         "     --[no-]error              print out error reports on stderr or otherwise\n"
@@ -849,6 +852,7 @@ static void dump_options(const struct options_t* opts)
         "quote-text:                    %s\n"
         "trim-spaces:                   %s\n"
         "newline-sep:                   %s\n"
+        "sort-keys:                     %s\n"
         "no-warning:                    %s\n"
         "no-error:                      %s\n"
         "verbose:                       %s\n"
@@ -898,6 +902,7 @@ static void dump_options(const struct options_t* opts)
         NOYES(quote_text),
         NOYES(trim_spaces),
         NOYES(newline_sep),
+        NOYES(sort_keys),
         NOYES(no_warning),
         NOYES(no_error),
         NOYES(verbose),
@@ -1331,6 +1336,7 @@ const struct options_t* options(int argc, char* argv[])
         .quote_text       = false,
         .trim_spaces      = false,
         .newline_sep      = false,
+        .sort_keys        = false,
         .no_warning       = false,
         .no_error         = false,
         .verbose          = false,
@@ -1395,6 +1401,7 @@ const struct options_t* options(int argc, char* argv[])
 #include "opt-sizes.def"
 
         newline_sep_opt      = 128,
+        sort_keys_opt,
         no_warning_opt,
         no_error_opt,
         dump_opts_opt,
@@ -1418,6 +1425,7 @@ const struct options_t* options(int argc, char* argv[])
         no_quote_text_opt,
         no_trim_spaces_opt,
         no_newline_sep_opt,
+        no_sort_keys_opt,
         no_no_warning_opt,
         no_no_error_opt,
         no_verbose_opt,
@@ -1494,6 +1502,8 @@ const struct options_t* options(int argc, char* argv[])
         { "no-trim-spaces",         0,       0, no_trim_spaces_opt },
         { "newline-sep",            0,       0, newline_sep_opt },
         { "no-newline-sep",         0,       0, no_newline_sep_opt },
+        { "sort-keys",              0,       0, sort_keys_opt },
+        { "no-sort-keys",           0,       0, no_sort_keys_opt },
         { "dump-options",           0,       0, dump_opts_opt },
         { "version",                0,       0, version_opt },
         { "warning",                0,       0, no_no_warning_opt },
@@ -1685,6 +1695,12 @@ const struct options_t* options(int argc, char* argv[])
         case no_newline_sep_opt:
             opts.newline_sep = false;
             break;
+        case sort_keys_opt:
+            opts.sort_keys = true;
+            break;
+        case no_sort_keys_opt:
+            opts.sort_keys = false;
+            break;
         case dump_opts_opt:
             bits.dump = true;
             break;
